==> bootstrap-rytmcms-1.1.0.tgz: package/templates/local/models/item.php <==
<?php
class Item extends Model {

  /**
   * #################
   * ### overrides ###
   */


  /** 
   * ###########
   * ### own ###
  */
  /**
   * Zwraca nazwę klas dla elementu DOM <html>
   * @return String
   */
  public function getHtmlClassName() {
    $classN = "item-type-" . $this->getType();
    return $classN;
  }
  /**
   * Focus point style
   * @return String
   */
  public function getBgFocusPointStyle($attr_name = 'file_focus') {
    if (!$this->getAttr($attr_name)) {
      return 'background-position: center';
    }
    return "background-position: " . $this->getAttr($attr_name) . "; ";
  }
  /**
   * IMG Focus point style
   * @return String
   */
  public function getImgFocusPointStyle($attr_name = 'file_focus') {
    if (!$this->getAttr($attr_name)) {
      return 'object-position: center';
    }
    return "object-position: " . $this->getAttr($attr_name) . "; ";
  }
  /**
   * Picture BOX params
   * @param String $size_prefix
   * @param String $attr_name
   * @return Array
   */
  public function getPictureBoxParams($size_prefix = "full", $attr_name = 'file', $focus_attr_name = 'file_focus') {
    return array(
      "imgXl" => $this->getImagePath($size_prefix . "_xl", $attr_name),
      "imgLg" => $this->getImagePath($size_prefix . "_lg", $attr_name),
      "imgMd" => $this->getImagePath($size_prefix . "_md", $attr_name),
      "imgSm" => $this->getImagePath($size_prefix . "_sm", $attr_name),
      "imgXs" => $this->getImagePath($size_prefix . "_xs", $attr_name),
      "alt" => $this->getMetaImgAlt(),
      "title" => $this->getMetaImgTitle(),
      "style" => $this->getAttr($focus_attr_name) ? $this->getImgFocusPointStyle($focus_attr_name) : null
    );
  }
  /**
   * ASwap ID with params
   * @return String
   */
  public function getAswapIdWithParams() {
    $id = "it-" . $this->getID();
    $paramsArr = WebessRequest::instance()->getParamsArr();
    $str = http_build_query($paramsArr);
    if ($str) {
      $id .= "_" . $str;
    }
    // check PAGIN page
    $request = TukiRequest::$current;
    $page = $request->getDataValue(TukiRequest::PARAM_PAGIN_PAGE);
    if ($page) {
      $id .= "_p" . $page;
    }
    return $id;
  }
  /**
   * Zwraca rządane dzieci
   */
  public function getRequestedChildren($limit = 0, $start = 0) {
    $adapter = $this->getRequestedChildrenAdapter();
    if ($limit > 0) {
      $adapter->setLimit($limit);
      $adapter->setStart($start);
    }
    return $this->getItems($adapter);
  }
  /**
   * Zwraca rządane dzieci
   */
  public function getRequestedChildrenTotal() {
    $adapter = $this->getRequestedChildrenAdapter();
    return $this->getItemsTotal($adapter);
  }
  /**
   * Zwraca adapter dla rządanych dzieci
   * @return ItemsAdapter
   */
  protected function getRequestedChildrenAdapter() {
    $adapter = new ItemsAdapter();
    $adapter->addParent($this->getID());
    $adapter->setOrder($this->getContentStructureChildrenOrder());
    return $adapter;
  }
  /**
  * Zwraca wartość (pojedynczą) klucza przekazywanego w adresie URL zapytania
  * Parametry zapytania (request params) są grupowane w parach, np:
  * ../parent/name,key1,value1,key2,value2
  * @param String $key
  * @return String
  **/
  public function getRequestParamValueSafe($key) {
    $result = null;
    $valArr =  WebessRequest::instance()->getParamValues($key);
    if (is_array($valArr) && isset($valArr[0])) {
      $resultSafe = Strings::escape($valArr[0], "html+js");
      $result = $resultSafe == $valArr[0] ? $resultSafe : null;
    }
    return $result;
  }

  
}

==> bootstrap-rytmcms-1.1.1.tgz: package/templates/local/models/item.php <==
<?php
class Item extends Model {

  /**
   * #################
   * ### overrides ###
   */


  /** 
   * ###########
   * ### own ###
  */
  /**
   * Zwraca nazwę klas dla elementu DOM <html>
   * @return String
   */
  public function getHtmlClassName() {
    $classN = "item-type-" . $this->getType();
    return $classN;
  }
  /**
   * Focus point style
   * @return String
   */
  public function getBgFocusPointStyle($attr_name = 'file_focus') {
    if (!$this->getAttr($attr_name)) {
      return 'background-position: center';
    }
    return "background-position: " . $this->getAttr($attr_name) . "; ";
  }
  /**
   * IMG Focus point style
   * @return String
   */
  public function getImgFocusPointStyle($attr_name = 'file_focus') {
    if (!$this->getAttr($attr_name)) {
      return 'object-position: center';
    }
    return "object-position: " . $this->getAttr($attr_name) . "; ";
  }
  /**
   * Picture BOX params
   * @param String $size_prefix
   * @param String $attr_name
   * @return Array
   */
  public function getPictureBoxParams($size_prefix = "full", $attr_name = 'file', $focus_attr_name = 'file_focus', $alt_image = null) {
    return array(
      "imgXl" => $this->getImagePath($size_prefix . "_xl", $attr_name, $alt_image),
      "imgLg" => $this->getImagePath($size_prefix . "_lg", $attr_name, $alt_image),
      "imgMd" => $this->getImagePath($size_prefix . "_md", $attr_name, $alt_image),
      "imgSm" => $this->getImagePath($size_prefix . "_sm", $attr_name, $alt_image),
      "imgXs" => $this->getImagePath($size_prefix . "_xs", $attr_name, $alt_image),
      "alt" => $this->getMetaImgAlt(),
      "title" => $this->getMetaImgTitle(),
      "style" => $this->getAttr($focus_attr_name) ? $this->getImgFocusPointStyle($focus_attr_name) : null
    );
  }
  /**
   * ASwap ID with params
   * @return String
   */
  public function getAswapIdWithParams() {
    $id = "it-" . $this->getID();
    $paramsArr = WebessRequest::instance()->getParamsArr();
    $str = http_build_query($paramsArr);
    if ($str) {
      $id .= "_" . $str;
    }
    // check PAGIN page
    $request = TukiRequest::$current;
    $page = $request->getDataValue(TukiRequest::PARAM_PAGIN_PAGE);
    if ($page) {
      $id .= "_p" . $page;
    }
    return $id;
  }
  /**
   * Zwraca rządane dzieci
   */
  public function getRequestedChildren($limit = 0, $start = 0) {
    $adapter = $this->getRequestedChildrenAdapter();
    if ($limit > 0) {
      $adapter->setLimit($limit);
      $adapter->setStart($start);
    }
    return $this->getItems($adapter);
  }
  /**
   * Zwraca rządane dzieci
   */
  public function getRequestedChildrenTotal() {
    $adapter = $this->getRequestedChildrenAdapter();
    return $this->getItemsTotal($adapter);
  }
  /**
   * Zwraca adapter dla rządanych dzieci
   * @return ItemsAdapter
   */
  protected function getRequestedChildrenAdapter() {
    $adapter = new ItemsAdapter();
    $adapter->addParent($this->getID());
    $adapter->setOrder($this->getContentStructureChildrenOrder());
    return $adapter;
  }
  /**
  * Zwraca wartość (pojedynczą) klucza przekazywanego w adresie URL zapytania
  * Parametry zapytania (request params) są grupowane w parach, np:
  * ../parent/name,key1,value1,key2,value2
  * @param String $key
  * @return String
  **/
  public function getRequestParamValueSafe($key) {
    $result = null;
    $valArr =  WebessRequest::instance()->getParamValues($key);
    if (is_array($valArr) && isset($valArr[0])) {
      $resultSafe = Strings::escape($valArr[0], "html+js");
      $result = $resultSafe == $valArr[0] ? $resultSafe : null;
    }
    return $result;
  }

  
}
